@@ -23,15 +23,15 @@ public:
 protected:
     void slotNextStep() override;
     virtual void synchronizeResource(const QStringList &lst) = 0;
-    Q_REQUIRED_RESULT virtual QString adaptResourcePath(const KSharedConfigPtr &resourceConfig, const QString &storedData) = 0;
-    Q_REQUIRED_RESULT virtual QString configLocation() const;
+    [[nodiscard]] virtual QString adaptResourcePath(const KSharedConfigPtr &resourceConfig, const QString &storedData) = 0;
+    [[nodiscard]] virtual QString configLocation() const;
     void restoreResources();
-    Q_REQUIRED_RESULT QString applicationName() const override;
+    [[nodiscard]] QString applicationName() const override;
 
 private:
-    Q_REQUIRED_RESULT bool isAConfigFile(const QString &name) const override;
+    [[nodiscard]] bool isAConfigFile(const QString &name) const override;
     void importkaddressBookConfig(const KArchiveFile *file, const QString &config, const QString &filename, const QString &prefix);
     void restoreConfig();
     void addSpecificResourceSettings(const KSharedConfig::Ptr &resourceConfig, const QString &resourceName, QMap<QString, QVariant> &settings) override;
-    Q_REQUIRED_RESULT QString installConfigLocation() const;
+    [[nodiscard]] QString installConfigLocation() const;
 };
