@@ -21,7 +21,7 @@ ExportAlarmJobInterfaceImpl::ExportAlarmJobInterfaceImpl(QObject *parent, Utils:
 
 ExportAlarmJobInterfaceImpl::~ExportAlarmJobInterfaceImpl() = default;
 
-QVector<Utils::AkonadiInstanceInfo> ExportAlarmJobInterfaceImpl::listOfResource()
+QList<Utils::AkonadiInstanceInfo> ExportAlarmJobInterfaceImpl::listOfResource()
 {
     return Utils::listOfResource();
 }
@@ -80,3 +80,5 @@ void ExportAlarmJobInterfaceImpl::convertCollectionIdsToRealPath(KConfigGroup &s
     ResourceConverterImpl converter;
     converter.convertCollectionIdsToRealPath(selectFolderNoteGroup, selectFolderNoteGroupStr);
 }
+
+#include "moc_exportalarmjobinterfaceimpl.cpp"
