@@ -22,15 +22,15 @@ public:
 protected:
     void slotNextStep() override;
     virtual void synchronizeResource(const QStringList &lst) = 0;
-    Q_REQUIRED_RESULT virtual QString adaptResourcePath(const KSharedConfigPtr &resourceConfig, const QString &storedData) = 0;
+    [[nodiscard]] virtual QString adaptResourcePath(const KSharedConfigPtr &resourceConfig, const QString &storedData) = 0;
 
     void restoreResources();
-    Q_REQUIRED_RESULT virtual QString configLocation() const;
-    Q_REQUIRED_RESULT QString applicationName() const override;
+    [[nodiscard]] virtual QString configLocation() const;
+    [[nodiscard]] QString applicationName() const override;
 
 private:
-    Q_REQUIRED_RESULT bool isAConfigFile(const QString &name) const override;
+    [[nodiscard]] bool isAConfigFile(const QString &name) const override;
     void importkalarmConfig(const KArchiveFile *kalarmFile, const QString &kalarmrc, const QString &filename, const QString &prefix);
     void restoreConfig();
-    Q_REQUIRED_RESULT QString installConfigLocation() const;
+    [[nodiscard]] QString installConfigLocation() const;
 };
