@@ -49,7 +49,7 @@ void ExportCalendarsJobInterfaceTestImpl::exportResourceToArchive(const QString
     slotCalendarJobTerminated();
 }
 
-QVector<Utils::AkonadiInstanceInfo> ExportCalendarsJobInterfaceTestImpl::listOfResource()
+QList<Utils::AkonadiInstanceInfo> ExportCalendarsJobInterfaceTestImpl::listOfResource()
 {
     return mListAkonadiInstanceInfo;
 }
@@ -100,3 +100,5 @@ QString ExportCalendarsJobInterfaceTestImpl::createResource(const QString &resou
     Q_UNREACHABLE();
     return {};
 }
+
+#include "moc_exportcalendarsjobinterfacetestimpl.cpp"
