@@ -55,7 +55,7 @@ void ExportMailJobInterfaceTest::exportMail()
     QFETCH(Utils::StoredTypes, options);
     std::unique_ptr<TestExportFile> file{new TestExportFile(this)};
     file->setPathConfig(configpath);
-    QVector<Utils::AkonadiInstanceInfo> lstInfo;
+    QList<Utils::AkonadiInstanceInfo> lstInfo;
     Utils::AkonadiInstanceInfo info;
 
     info.identifier = QStringLiteral("akonadi_mbox_resource_1");
@@ -100,3 +100,5 @@ void ExportMailJobInterfaceTest::exportMail()
     file->start();
     delete exportMail;
 }
+
+#include "moc_exportmailjobinterfacetest.cpp"
