@@ -23,22 +23,19 @@ protected:
 
     void convertCollectionIdsToRealPath(KConfigGroup &group, const QString &currentKey, const QString &prefixCollection) override;
 
-    Q_REQUIRED_RESULT Akonadi::Collection::Id convertFolderPathToCollectionId(const QString &path) override;
+    [[nodiscard]] Akonadi::Collection::Id convertFolderPathToCollectionId(const QString &path) override;
 
-    Q_REQUIRED_RESULT QVector<MailCommon::MailFilter *> filters() override;
+    [[nodiscard]] QList<MailCommon::MailFilter *> filters() override;
 
-    Q_REQUIRED_RESULT QString convertToFullCollectionPath(const qlonglong collectionValue) override;
+    [[nodiscard]] QString convertToFullCollectionPath(const qlonglong collectionValue) override;
     void exportResourceToArchive(const QString &archivePath, const QString &url, const QString &identifier) override;
-    Q_REQUIRED_RESULT QVector<Utils::AkonadiInstanceInfo> listOfResource() override;
-    Q_REQUIRED_RESULT QString storeResources(KZip *archive, const QString &identifier, const QString &path) override;
-    Q_REQUIRED_RESULT QString resourcePath(const QString &identifier) const override;
+    [[nodiscard]] QList<Utils::AkonadiInstanceInfo> listOfResource() override;
+    [[nodiscard]] QString storeResources(KZip *archive, const QString &identifier, const QString &path) override;
+    [[nodiscard]] QString resourcePath(const QString &identifier) const override;
     void backupMailResourceFile(const QString &agentIdentifier, const QString &defaultPath) override;
-    Q_REQUIRED_RESULT QString adaptNewResourceUrl(bool overwriteResources, const KSharedConfig::Ptr &resourceConfig, const QString &storePath) override;
-    Q_REQUIRED_RESULT QString createResource(const QString &resources,
-                                             const QString &name,
-                                             const QMap<QString, QVariant> &settings,
-                                             bool synchronizeTree) override;
-    Q_REQUIRED_RESULT QVector<uint> listIdentityUoid() const override;
+    [[nodiscard]] QString adaptNewResourceUrl(bool overwriteResources, const KSharedConfig::Ptr &resourceConfig, const QString &storePath) override;
+    [[nodiscard]] QString createResource(const QString &resources, const QString &name, const QMap<QString, QVariant> &settings, bool synchronizeTree) override;
+    [[nodiscard]] QList<uint> listIdentityUoid() const override;
     void exportFilters() override;
     void exportFolderAttributes() override;
 };
