@@ -24,7 +24,7 @@ ExportCalendarJobInterfaceImpl::ExportCalendarJobInterfaceImpl(QObject *parent,
 
 ExportCalendarJobInterfaceImpl::~ExportCalendarJobInterfaceImpl() = default;
 
-QVector<Utils::AkonadiInstanceInfo> ExportCalendarJobInterfaceImpl::listOfResource()
+QList<Utils::AkonadiInstanceInfo> ExportCalendarJobInterfaceImpl::listOfResource()
 {
     return Utils::listOfResource();
 }
@@ -89,3 +89,5 @@ ExportCalendarJobInterfaceImpl::createResource(const QString &resources, const Q
     Q_UNREACHABLE();
     return {};
 }
+
+#include "moc_exportcalendarjobinterfaceimpl.cpp"
