@@ -23,19 +23,19 @@ public:
 protected:
     void slotNextStep() override;
     virtual void synchronizeResource(const QStringList &lst) = 0;
-    Q_REQUIRED_RESULT virtual QString adaptResourcePath(const KSharedConfigPtr &resourceConfig, const QString &storedData) = 0;
+    [[nodiscard]] virtual QString adaptResourcePath(const KSharedConfigPtr &resourceConfig, const QString &storedData) = 0;
 
-    Q_REQUIRED_RESULT virtual QString configLocation() const;
-    Q_REQUIRED_RESULT QString applicationName() const override;
+    [[nodiscard]] virtual QString configLocation() const;
+    [[nodiscard]] QString applicationName() const override;
 
 private:
-    Q_REQUIRED_RESULT bool isAConfigFile(const QString &name) const override;
+    [[nodiscard]] bool isAConfigFile(const QString &name) const override;
     void importkorganizerConfig(const KArchiveFile *file, const QString &config, const QString &filename, const QString &prefix);
     void importeventViewConfig(const KArchiveFile *file, const QString &config, const QString &filename, const QString &prefix);
     void importKalendarConfig(const KArchiveFile *file, const QString &config, const QString &filename, const QString &prefix);
     void restoreResources();
     void restoreConfig();
     void addSpecificResourceSettings(const KSharedConfig::Ptr &resourceConfig, const QString &resourceName, QMap<QString, QVariant> &settings) override;
-    Q_REQUIRED_RESULT QString installConfigLocation() const;
+    [[nodiscard]] QString installConfigLocation() const;
     void convertResourceColors(const KSharedConfig::Ptr &config);
 };
