@@ -46,13 +46,13 @@ protected:
     virtual void registerSpecialCollection(Akonadi::SpecialMailCollections::Type type, qint64 colId) = 0;
     virtual void synchronizeResource(const QStringList &lst) = 0;
     virtual void importFilters(const QString &filename) = 0;
-    Q_REQUIRED_RESULT virtual QString configLocation() const = 0;
-    Q_REQUIRED_RESULT virtual QString adaptResourcePath(const KSharedConfigPtr &resourceConfig, const QString &storedData) = 0;
+    [[nodiscard]] virtual QString configLocation() const = 0;
+    [[nodiscard]] virtual QString adaptResourcePath(const KSharedConfigPtr &resourceConfig, const QString &storedData) = 0;
     virtual void addNewIdentity(const QString &name, KConfigGroup &group, int defaultIdentities, int oldUid) = 0;
     virtual void importCustomMailTransport(const QString &identifierValue, const KConfigGroup &group, int defaultTransport, int transportId) = 0;
     virtual void importSmtpMailTransport(const SmtpMailTransport &smtpMailTransport, int defaultTransport, int transportId) = 0;
 
-    Q_REQUIRED_RESULT QString applicationName() const override;
+    [[nodiscard]] QString applicationName() const override;
 
     virtual void importFolderAttributes() = 0;
 
