@@ -13,43 +13,43 @@ class PIMDATAEXPORTER_TESTS_EXPORT SmtpMailTransport
 {
 public:
     explicit SmtpMailTransport(const KConfigGroup &group);
-    Q_REQUIRED_RESULT QString name() const;
+    [[nodiscard]] QString name() const;
     void setName(const QString &name);
 
-    Q_REQUIRED_RESULT QString host() const;
+    [[nodiscard]] QString host() const;
     void setHost(const QString &host);
 
-    Q_REQUIRED_RESULT int port() const;
+    [[nodiscard]] int port() const;
     void setPort(int port);
 
-    Q_REQUIRED_RESULT QString userName() const;
+    [[nodiscard]] QString userName() const;
     void setUserName(const QString &userName);
 
-    Q_REQUIRED_RESULT QString precommand() const;
+    [[nodiscard]] QString precommand() const;
     void setPrecommand(const QString &precommand);
 
-    Q_REQUIRED_RESULT bool requiresAuthentication() const;
+    [[nodiscard]] bool requiresAuthentication() const;
     void setRequiresAuthentication(bool requiresAuthentication);
 
-    Q_REQUIRED_RESULT bool specifyHostname() const;
+    [[nodiscard]] bool specifyHostname() const;
     void setSpecifyHostname(bool specifyHostname);
 
-    Q_REQUIRED_RESULT QString localHostname() const;
+    [[nodiscard]] QString localHostname() const;
     void setLocalHostname(const QString &localHostname);
 
-    Q_REQUIRED_RESULT bool specifySenderOverwriteAddress() const;
+    [[nodiscard]] bool specifySenderOverwriteAddress() const;
     void setSpecifySenderOverwriteAddress(bool specifySenderOverwriteAddress);
 
-    Q_REQUIRED_RESULT bool storePassword() const;
+    [[nodiscard]] bool storePassword() const;
     void setStorePassword(bool storePassword);
 
-    Q_REQUIRED_RESULT QString senderOverwriteAddress() const;
+    [[nodiscard]] QString senderOverwriteAddress() const;
     void setSenderOverwriteAddress(const QString &senderOverwriteAddress);
 
-    Q_REQUIRED_RESULT int encryption() const;
+    [[nodiscard]] int encryption() const;
     void setEncryption(int encryption);
 
-    Q_REQUIRED_RESULT int authenticationType() const;
+    [[nodiscard]] int authenticationType() const;
     void setAuthenticationType(int authenticationType);
 
 private:
