@@ -21,7 +21,7 @@ ExportNotesJobInterfaceImpl::ExportNotesJobInterfaceImpl(QObject *parent, Utils:
 
 ExportNotesJobInterfaceImpl::~ExportNotesJobInterfaceImpl() = default;
 
-QVector<Utils::AkonadiInstanceInfo> ExportNotesJobInterfaceImpl::listOfResource()
+QList<Utils::AkonadiInstanceInfo> ExportNotesJobInterfaceImpl::listOfResource()
 {
     return Utils::listOfResource();
 }
@@ -75,3 +75,5 @@ ExportNotesJobInterfaceImpl::createResource(const QString &resources, const QStr
     Q_UNREACHABLE();
     return {};
 }
+
+#include "moc_exportnotesjobinterfaceimpl.cpp"
