@@ -6,8 +6,8 @@
 
 #include "backupfilestructureinfodialog.h"
 
-#include <KPIMTextEdit/PlainTextEditor>
-#include <KPIMTextEdit/PlainTextEditorWidget>
+#include <TextCustomEditor/PlainTextEditor>
+#include <TextCustomEditor/PlainTextEditorWidget>
 
 #include <KLocalizedString>
 #include <KSharedConfig>
@@ -30,7 +30,7 @@ static const char myBackupFileStructureInfoDialogGroupName[] = "BackupFileStruct
 }
 BackupFileStructureInfoDialog::BackupFileStructureInfoDialog(QWidget *parent)
     : QDialog(parent)
-    , mEditor(new KPIMTextEdit::PlainTextEditorWidget(this))
+    , mEditor(new TextCustomEditor::PlainTextEditorWidget(this))
 {
     setWindowTitle(i18nc("@title:window", "Archive File Structure"));
     auto mainLayout = new QVBoxLayout(this);
@@ -70,14 +70,16 @@ void BackupFileStructureInfoDialog::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(600, 400));
-    KConfigGroup group(KSharedConfig::openStateConfig(), myBackupFileStructureInfoDialogGroupName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myBackupFileStructureInfoDialogGroupName));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void BackupFileStructureInfoDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), myBackupFileStructureInfoDialogGroupName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myBackupFileStructureInfoDialogGroupName));
     KWindowConfig::saveWindowSize(windowHandle(), group);
     group.sync();
 }
+
+#include "moc_backupfilestructureinfodialog.cpp"
