@@ -22,7 +22,7 @@ public:
     void setExportWindow(PimDataExporterWindow *exporterWindow);
     void handleCommandLine();
 
-    Q_REQUIRED_RESULT bool parseUserFeedback() const;
+    [[nodiscard]] bool parseUserFeedback() const;
 
 public Q_SLOTS:
     void slotActivateRequested(const QStringList &arguments, const QString &workingDirectory);
