@@ -27,6 +27,7 @@
 
 #include <Akonadi/ControlGui>
 
+#include <KAboutData>
 #include <KActionCollection>
 #include <KFileWidget>
 #include <KLocalizedString>
@@ -40,6 +41,7 @@
 #include <QPointer>
 #include <QStandardPaths>
 #include <QStatusBar>
+#include <QVBoxLayout>
 
 #include <dialog/pimdataexporterconfiguredialog.h>
 #ifdef WITH_KUSERFEEDBACK
@@ -48,10 +50,36 @@
 #include <KUserFeedback/Provider>
 #endif
 
+#include <PimCommon/NeedUpdateVersionUtils>
+#include <PimCommon/NeedUpdateVersionWidget>
+
+// signal handler for SIGINT & SIGTERM
+#ifdef Q_OS_UNIX
+#include <KSignalHandler>
+#include <signal.h>
+#include <unistd.h>
+#endif
+
 PimDataExporterWindow::PimDataExporterWindow(QWidget *parent)
     : KXmlGuiWindow(parent)
     , mLogWidget(new LogWidget(this))
 {
+#ifdef Q_OS_UNIX
+    /**
+     * Set up signal handler for SIGINT and SIGTERM
+     */
+    KSignalHandler::self()->watchSignal(SIGINT);
+    KSignalHandler::self()->watchSignal(SIGTERM);
+    connect(KSignalHandler::self(), &KSignalHandler::signalReceived, this, [this](int signal) {
+        if (signal == SIGINT || signal == SIGTERM) {
+            // Intercept console.
+            printf("Shutting down...\n");
+            if (!mInProgress) {
+                close();
+            }
+        }
+    });
+#endif
     // Initialize filtermanager
     (void)MailCommon::FilterManager::instance();
 #ifdef WITH_KUSERFEEDBACK
@@ -65,7 +93,21 @@ PimDataExporterWindow::PimDataExporterWindow(QWidget *parent)
     setupActions(true);
     setupGUI(Keys | StatusBar | Save | Create, QStringLiteral("pimdataexporter.rc"));
 
-    setCentralWidget(mLogWidget);
+    auto mainWidget = new QWidget(this);
+    auto mainWidgetLayout = new QVBoxLayout(mainWidget);
+    mainWidgetLayout->setContentsMargins({});
+    mainWidgetLayout->setSpacing(0);
+    if (PimCommon::NeedUpdateVersionUtils::checkVersion()) {
+        const auto status = PimCommon::NeedUpdateVersionUtils::obsoleteVersionStatus(KAboutData::applicationData().version(), QDate::currentDate());
+        if (status != PimCommon::NeedUpdateVersionUtils::ObsoleteVersion::NotObsoleteYet) {
+            auto needUpdateVersionWidget = new PimCommon::NeedUpdateVersionWidget(this);
+            mainWidgetLayout->addWidget(needUpdateVersionWidget);
+            needUpdateVersionWidget->setObsoleteVersion(status);
+        }
+    }
+    mainWidgetLayout->addWidget(mLogWidget);
+
+    setCentralWidget(mainWidget);
     resize(800, 600);
     Akonadi::ControlGui::widgetNeedsAkonadi(this);
     statusBar()->hide();
@@ -244,6 +286,7 @@ void PimDataExporterWindow::slotUpdateActions(bool inAction)
     mArchiveStructureInfo->setEnabled(!inAction);
     mShowArchiveInformationsAction->setEnabled(!inAction);
     mShowArchiveInformationsAboutCurrentArchiveAction->setEnabled(!inAction && !mLastArchiveFileName.isEmpty());
+    mInProgress = inAction;
 }
 
 void PimDataExporterWindow::slotRestoreFile(const QUrl &url)
